==> inkscape_0.43.orig.tar.gz: inkscape-0.43/src/preferences-skeleton.h <==
#ifndef SEEN_PREFERENCES_SKELETON_H
#define SEEN_PREFERENCES_SKELETON_H

#include <inkscape_version.h>

static char const preferences_skeleton[] =
"<inkscape version=\"" INKSCAPE_VERSION "\"\n"
"  xmlns:sodipodi=\"http://inkscape.sourceforge.net/DTD/sodipodi-0.dtd\"\n"
"  xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\">\n"
"  <group id=\"window\">\n"
"    <group id=\"menu\" state=\"1\"/>\n"
"    <group id=\"commands\" state=\"1\"/>\n"
"    <group id=\"toppanel\" state=\"1\"/>\n"
"    <group id=\"toolbox\" state=\"1\"/>\n"
"    <group id=\"statusbar\" state=\"1\"/>\n"
"    <group id=\"rulers\" state=\"1\"/>\n"
"    <group id=\"scrollbars\" state=\"1\"/>\n"
"  </group>\n"
"  <group id=\"fullscreen\">\n"
"    <group id=\"menu\" state=\"1\"/>\n"
"    <group id=\"commands\" state=\"1\"/>\n"
"    <group id=\"toppanel\" state=\"1\"/>\n"
"    <group id=\"toolbox\" state=\"1\"/>\n"
"    <group id=\"statusbar\" state=\"1\"/>\n"
"    <group id=\"rulers\" state=\"1\"/>\n"
"    <group id=\"scrollbars\" state=\"1\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"documents\">\n"
"    <group id=\"recent\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"template\">\n"
"    <sodipodi:namedview\n"
"       id=\"base\"\n"
"       pagecolor=\"#ffffff\"\n"
"       bordercolor=\"#666666\"\n"
"       borderopacity=\"1.0\"\n"
"       inkscape:pageopacity=\"0.0\"\n"
"       inkscape:pageshadow=\"2\"\n"
"       inkscape:window-width=\"640\"\n"
"       inkscape:window-height=\"480\" />\n"
"  </group>\n"
"\n"
"  <group id=\"tools\"\n"
"         style=\"fill:none;fill-opacity:0.75;\n"
"                 stroke:black;stroke-opacity:1;stroke-width:1px;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
"    <group id=\"shapes\" style=\"fill-rule:evenodd;\" selcue=\"1\" gradientdrag=\"1\">\n"
"      <eventcontext id=\"rect\" style=\"fill:blue;\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"arc\" style=\"fill:red;\" end=\"0\" start=\"0\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"star\" magnitude=\"5\" style=\"fill:yellow;\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"spiral\" style=\"fill:none;stroke:black;\" usecurrent=\"0\"/>\n"
"    </group>\n"
"    <group id=\"freehand\"\n"
"         style=\"fill:none;fill-rule:evenodd;stroke:black;stroke-opacity:1;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
"      <eventcontext id=\"pencil\" tolerance=\"4.0\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
"      <eventcontext id=\"pen\" mode=\"drag\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
"    </group>\n"
"    <eventcontext id=\"calligraphic\" style=\"fill:black;fill-opacity:1;fill-rule:nonzero;stroke:none;\"\n"
"                       mass=\"0.02\" drag=\"1\" angle=\"30\" width=\"0.15\" thinning=\"0.1\" flatness=\"0.9\"  usecurrent=\"0\"\n"
"                       usepressure=\"0\" usetilt=\"0\"/>\n"
"    <eventcontext id=\"text\"  usecurrent=\"0\" gradientdrag=\"1\"\n"
"                  style=\"fill:black;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans;font-style:normal;font-weight:normal;font-size:12px;\" selcue=\"1\"/>\n"
"    <eventcontext id=\"nodes\" selcue=\"1\" gradientdrag=\"1\"/>\n"
"    <eventcontext id=\"gradient\" selcue=\"1\"/>\n"
"    <eventcontext id=\"zoom\" selcue=\"1\" gradientdrag=\"0\"/>\n"
"    <eventcontext id=\"dropper\" selcue=\"1\" gradientdrag=\"1\"/>\n"
"    <eventcontext id=\"select\" selcue=\"1\" gradientdrag=\"0\"/>\n"
"    <eventcontext id=\"connector\" style=\"fill:none;fill-rule:evenodd;stroke:black;stroke-opacity:1;stroke-linejoin:miter;stroke-width:1px;stroke-linecap:butt;\" selcue=\"1\"/>\n"
"  </group>\n"
"  <group id=\"palette\">\n"
"    <group id=\"dashes\">\n"
"      <dash id=\"solid\" style=\"stroke-dasharray:none\"/>\n"
"      <dash id=\"dash-1-1\" style=\"stroke-dasharray:1,1\"/>\n"
"      <dash id=\"dash-1-2\" style=\"stroke-dasharray:1,2\"/>\n"
"      <dash id=\"dash-1-3\" style=\"stroke-dasharray:1,3\"/>\n"
"      <dash id=\"dash-1-4\" style=\"stroke-dasharray:1,4\"/>\n"
"      <dash id=\"dash-1-6\" style=\"stroke-dasharray:1,6\"/>\n"
"      <dash id=\"dash-1-8\" style=\"stroke-dasharray:1,8\"/>\n"
"      <dash id=\"dash-1-12\" style=\"stroke-dasharray:1,12\"/>\n"
"      <dash id=\"dash-1-24\" style=\"stroke-dasharray:1,24\"/>\n"
"      <dash id=\"dash-1-48\" style=\"stroke-dasharray:1,48\"/>\n"
"      <dash id=\"dash-2-1\" style=\"stroke-dasharray:2,1\"/>\n"
"      <dash id=\"dash-3-1\" style=\"stroke-dasharray:3,1\"/>\n"
"      <dash id=\"dash-4-1\" style=\"stroke-dasharray:4,1\"/>\n"
"      <dash id=\"dash-6-1\" style=\"stroke-dasharray:6,1\"/>\n"
"      <dash id=\"dash-8-1\" style=\"stroke-dasharray:8,1\"/>\n"
"      <dash id=\"dash-12-1\" style=\"stroke-dasharray:12,1\"/>\n"
"      <dash id=\"dash-24-1\" style=\"stroke-dasharray:24,1\"/>\n"
"      <dash id=\"dash-2-2\" style=\"stroke-dasharray:2,2\"/>\n"
"      <dash id=\"dash-3-3\" style=\"stroke-dasharray:3,3\"/>\n"
"      <dash id=\"dash-4-4\" style=\"stroke-dasharray:4,4\"/>\n"
"      <dash id=\"dash-6-6\" style=\"stroke-dasharray:6,6\"/>\n"
"      <dash id=\"dash-8-8\" style=\"stroke-dasharray:8,8\"/>\n"
"      <dash id=\"dash-12-12\" style=\"stroke-dasharray:12,12\"/>\n"
"      <dash id=\"dash-24-24\" style=\"stroke-dasharray:24,24\"/>\n"
"      <dash id=\"dash-2-4\" style=\"stroke-dasharray:2,4\"/>\n"
"      <dash id=\"dash-4-2\" style=\"stroke-dasharray:4,2\"/>\n"
"      <dash id=\"dash-2-6\" style=\"stroke-dasharray:2,6\"/>\n"
"      <dash id=\"dash-6-2\" style=\"stroke-dasharray:6,2\"/>\n"
"      <dash id=\"dash-4-8\" style=\"stroke-dasharray:4,8\"/>\n"
"      <dash id=\"dash-8-4\" style=\"stroke-dasharray:8,4\"/>\n"
"      <dash id=\"dash-2-1-012-1\" style=\"stroke-dasharray:2,1,0.5,1\"/>\n"
"      <dash id=\"dash-4-2-1-2\" style=\"stroke-dasharray:4,2,1,2\"/>\n"
"      <dash id=\"dash-8-2-1-2\" style=\"stroke-dasharray:8,2,1,2\"/>\n"
"      <dash id=\"dash-012-012\" style=\"stroke-dasharray:0.5,0.5\"/>\n"
"      <dash id=\"dash-014-014\" style=\"stroke-dasharray:0.25,0.25\"/>\n"
"      <dash id=\"dash-0110-0110\" style=\"stroke-dasharray:0.1,0.1\"/>\n"
"      <dash id=\"dash-0150-0150\" style=\"stroke-dasharray:0.02,0.02\"/>\n"
"    </group>\n"
"  </group>\n"
"  <group id=\"colorselector\" page=\"0\"/>\n"
"  <group id=\"dialogs\">\n"
"    <group id=\"toolbox\"/>\n"
"    <group id=\"fillstroke\"/>\n"
"    <group id=\"textandfont\"/>\n"
"    <group id=\"transformation\"/>\n"
"    <group id=\"align\"/>\n"
"    <group id=\"xml\"/>\n"
"    <group id=\"find\"/>\n"
"    <group id=\"documentoptions\"/>\n"
"    <group id=\"preferences\"/>\n"
"    <group id=\"gradienteditor\"/>\n"
"    <group id=\"object\"/>\n"
"    <group id=\"export\">\n"
"      <group id=\"exportarea\"/>\n"
"      <group id=\"defaultxdpi\"/>\n"
"    </group>\n"
"    <group id=\"save_as\" default=\"\" append_extension=\"1\" path=\"\"/>\n"
"    <group id=\"open\" path=\"\"/>\n"
"    <group id=\"debug\" redirect=\"0\"/>\n"
"    <group id=\"clonetiler\" />\n"
"    <group id=\"gridtiler\" />\n"
"    <group id=\"extension-error\" show-on-startup=\"0\"/>\n"
"    <group id=\"memory\" />\n"
"    <group id=\"messages\" />\n"
"    <group id=\"swatches\" />\n"
"    <group id=\"iconpreview\" />\n"
"    <group id=\"aboutextensions\" />\n"
"    <group id=\"treeeditor\" />\n"
"    <group id=\"layereditor\" />\n"
"    <group id=\"extensioneditor\" />\n"
"    <group id=\"trace\" />\n"
"    <group id=\"script\" />\n"
"    <group id=\"input\" />\n"
"  </group>\n"
"  <group id=\"printing\">\n"
"    <settings id=\"ps\"/>\n"
"    <group id=\"debug\" add-label-comments=\"0\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"options\">\n"
"    <group id=\"nudgedistance\" value=\"2\"/>\n"
"    <group id=\"rotationsnapsperpi\" value=\"12\"/>\n"
"    <group id=\"cursortolerance\" value=\"8.0\"/>\n"
"    <group id=\"dragtolerance\" value=\"4.0\"/>\n"
"    <group id=\"savewindowgeometry\" value=\"1\"/>\n"
"    <group id=\"defaultoffsetwidth\" value=\"2\"/>\n"
"    <group id=\"defaultscale\" value=\"2\"/>\n"
"    <group id=\"maxrecentdocuments\" value=\"36\"/>\n"
"    <group id=\"zoomincrement\" value=\"1.414213562\"/>\n"
"    <group id=\"keyscroll\" value=\"10\"/>\n"
"    <group id=\"wheelscroll\" value=\"40\"/>\n"
"    <group id=\"transientpolicy\" value=\"1\"/>\n"
"    <group id=\"scrollingacceleration\" value=\"0.35\"/>\n"
"    <group id=\"autoscrollspeed\" value=\"0.7\"/>\n"
"    <group id=\"autoscrolldistance\" value=\"-10\"/>\n"
"    <group id=\"simplifythreshold\" value=\"0.002\"/>\n"
"    <group id=\"dialogsskiptaskbar\" value=\"1\"/>\n"
"    <group id=\"arenatilescachesize\" value=\"8192\"/>\n"
"    <group id=\"preservetransform\" value=\"0\"/>\n"
"    <group id=\"clonecompensation\" value=\"1\"/>\n"
"    <group id=\"cloneorphans\" value=\"0\"/>\n"
"    <group id=\"stickyzoom\" value=\"0\"/>\n"
"    <group id=\"selcue\" value=\"2\"/>\n"
"    <group id=\"importbitmapsasimages\" value=\"1\"/>\n"
"    <group id=\"transform\" stroke=\"1\" rectcorners=\"0\" pattern=\"1\" gradient=\"1\" />\n"
"    <group id=\"kbselection\" inlayer=\"1\" onlyvisible=\"1\" onlysensitive=\"1\" />\n"
"    <group id=\"createbitmap\" minsize=\"250\"/>\n"
"    <group id=\"compassangledisplay\" value=\"0\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"extensions\" show-effects-menu=\"0\">"
"  </group>\n"
"\n"
"  <group id=\"desktop\""
"         style=\"\">\n"
"  </group>\n"
"\n"
"  <group id=\"devices\">\n"
"  </group>\n"
"\n"
"  <group\n"
"     id=\"iconpreview\">\n"
"    <group\n"
"       id=\"sizes\">\n"
"      <group\n"
"         id=\"default\">\n"
"        <group\n"
"           value=\"16\"\n"
"           show=\"1\"\n"
"           id=\"size16\" />\n"
"        <group\n"
"           value=\"24\"\n"
"           show=\"1\"\n"
"           id=\"size24\" />\n"
"        <group\n"
"           value=\"32\"\n"
"           show=\"1\"\n"
"           id=\"size32\" />\n"
"        <group\n"
"           value=\"48\"\n"
"           show=\"1\"\n"
"           id=\"size48\" />\n"
"        <group\n"
"           value=\"50\"\n"
"           show=\"0\"\n"
"           id=\"size50\" />\n"
"        <group\n"
"           value=\"64\"\n"
"           show=\"0\"\n"
"           id=\"size64\" />\n"
"        <group\n"
"           value=\"72\"\n"
"           show=\"0\"\n"
"           id=\"size72\" />\n"
"        <group\n"
"           value=\"80\"\n"
"           show=\"0\"\n"
"           id=\"size80\" />\n"
"        <group\n"
"           value=\"96\"\n"
"           show=\"0\"\n"
"           id=\"size96\" />\n"
"        <group\n"
"           value=\"128\"\n"
"           show=\"1\"\n"
"           id=\"size128\" />\n"
"        <group\n"
"           value=\"256\"\n"
"           show=\"0\"\n"
"           id=\"size256\" />\n"
"      </group>\n"
"    </group>\n"
"  </group>\n"
"\n"
"</inkscape>\n";

#define PREFERENCES_SKELETON_SIZE (sizeof(preferences_skeleton) - 1)


#endif /* !SEEN_PREFERENCES_SKELETON_H */

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=c++:expandtab:shiftwidth=4:tabstop=8:softtabstop=4 :

==> inkscape_0.44.1.orig.tar.gz: inkscape-0.44.1/src/preferences-skeleton.h <==
#ifndef SEEN_PREFERENCES_SKELETON_H
#define SEEN_PREFERENCES_SKELETON_H

#include <inkscape_version.h>

static char const preferences_skeleton[] =
"<inkscape version=\"" INKSCAPE_VERSION "\"\n"
"  xmlns:sodipodi=\"http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd\"\n"
"  xmlns:inkscape=\"http://www.inkscape.org/namespaces/inkscape\">\n"
"  <group id=\"window\">\n"
"    <group id=\"menu\" state=\"1\"/>\n"
"    <group id=\"commands\" state=\"1\"/>\n"
"    <group id=\"toppanel\" state=\"1\"/>\n"
"    <group id=\"toolbox\" state=\"1\"/>\n"
"    <group id=\"statusbar\" state=\"1\"/>\n"
"    <group id=\"panels\" state=\"1\"/>\n"
"    <group id=\"rulers\" state=\"1\"/>\n"
"    <group id=\"scrollbars\" state=\"1\"/>\n"
"  </group>\n"
"  <group id=\"fullscreen\">\n"
"    <group id=\"menu\" state=\"1\"/>\n"
"    <group id=\"commands\" state=\"1\"/>\n"
"    <group id=\"toppanel\" state=\"1\"/>\n"
"    <group id=\"toolbox\" state=\"1\"/>\n"
"    <group id=\"statusbar\" state=\"1\"/>\n"
"    <group id=\"panels\" state=\"1\"/>\n"
"    <group id=\"rulers\" state=\"1\"/>\n"
"    <group id=\"scrollbars\" state=\"1\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"documents\">\n"
"    <group id=\"recent\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"template\">\n"
"    <sodipodi:namedview\n"
"       id=\"base\"\n"
"       pagecolor=\"#ffffff\"\n"
"       bordercolor=\"#666666\"\n"
"       borderopacity=\"1.0\"\n"
"       objecttolerance=\"10.0\"\n"
"       gridtolerance=\"10.0\"\n"
"       guidetolerance=\"10.0\"\n"
"       inkscape:pageopacity=\"0.0\"\n"
"       inkscape:pageshadow=\"2\"\n"
"       inkscape:window-width=\"640\"\n"
"       inkscape:window-height=\"480\" />\n"
"  </group>\n"
"\n"
"  <group id=\"tools\"\n"
"         style=\"fill:none;stroke:black;stroke-opacity:1;stroke-width:1px;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
"    <group id=\"shapes\" style=\"fill-rule:evenodd;\" selcue=\"1\" gradientdrag=\"1\">\n"
"      <eventcontext id=\"rect\" style=\"fill:blue;\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"arc\" style=\"fill:red;\" end=\"0\" start=\"0\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"star\" magnitude=\"5\" style=\"fill:yellow;\" usecurrent=\"1\"/>\n"
"      <eventcontext id=\"spiral\" style=\"fill:none;\" usecurrent=\"0\"/>\n"
"    </group>\n"
"    <group id=\"freehand\"\n"
"         style=\"fill:none;fill-rule:evenodd;stroke:black;stroke-opacity:1;stroke-linejoin:miter;stroke-linecap:butt;\">\n"
"      <eventcontext id=\"pencil\" tolerance=\"4.0\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
"      <eventcontext id=\"pen\" mode=\"drag\" selcue=\"1\" style=\"stroke-width:1px;\" usecurrent=\"0\"/>\n"
"    </group>\n"
"    <eventcontext id=\"calligraphic\" style=\"fill:black;fill-opacity:1;fill-rule:nonzero;stroke:none;\"\n"
"                       mass=\"0.02\" drag=\"1\" angle=\"30\" width=\"0.15\" thinning=\"0.1\" flatness=\"0.9\"  usecurrent=\"1\"\n"
"                       usepressure=\"0\" usetilt=\"0\" keep_selected=\"1\"/>\n"
"    <eventcontext id=\"text\"  usecurrent=\"0\" gradientdrag=\"1\"\n" 
"                       font_sample=\"AaBbCcIiPpQq12369$\342\202\254\302\242?.;/()\"\n"
"                  style=\"fill:black;fill-opacity:1;stroke:none;font-family:Bitstream Vera Sans;font-style:normal;font-weight:normal;font-size:12px;\" selcue=\"1\"/>\n"
"    <eventcontext id=\"nodes\" selcue=\"1\" gradientdrag=\"1\" show_handles=\"1\" sculpting_profile=\"1\" />\n"
"    <eventcontext id=\"gradient\" selcue=\"1\"/>\n"
"    <eventcontext id=\"zoom\" selcue=\"1\" gradientdrag=\"0\"/>\n"
"    <eventcontext id=\"dropper\" selcue=\"1\" gradientdrag=\"1\"/>\n"
"    <eventcontext id=\"select\" selcue=\"1\" gradientdrag=\"0\"/>\n"
"    <eventcontext id=\"connector\" style=\"fill:none;fill-rule:evenodd;stroke:black;stroke-opacity:1;stroke-linejoin:miter;stroke-width:1px;stroke-linecap:butt;\" selcue=\"1\"/>\n"
"  </group>\n"
"  <group id=\"palette\">\n"
"    <group id=\"dashes\">\n"
"      <dash id=\"solid\" style=\"stroke-dasharray:none\"/>\n"
"      <dash id=\"dash-1-1\" style=\"stroke-dasharray:1,1\"/>\n"
"      <dash id=\"dash-1-2\" style=\"stroke-dasharray:1,2\"/>\n"
"      <dash id=\"dash-1-3\" style=\"stroke-dasharray:1,3\"/>\n"
"      <dash id=\"dash-1-4\" style=\"stroke-dasharray:1,4\"/>\n"
"      <dash id=\"dash-1-6\" style=\"stroke-dasharray:1,6\"/>\n"
"      <dash id=\"dash-1-8\" style=\"stroke-dasharray:1,8\"/>\n"
"      <dash id=\"dash-1-12\" style=\"stroke-dasharray:1,12\"/>\n"
"      <dash id=\"dash-1-24\" style=\"stroke-dasharray:1,24\"/>\n"
"      <dash id=\"dash-1-48\" style=\"stroke-dasharray:1,48\"/>\n"
"      <dash id=\"dash-2-1\" style=\"stroke-dasharray:2,1\"/>\n"
"      <dash id=\"dash-3-1\" style=\"stroke-dasharray:3,1\"/>\n"
"      <dash id=\"dash-4-1\" style=\"stroke-dasharray:4,1\"/>\n"
"      <dash id=\"dash-6-1\" style=\"stroke-dasharray:6,1\"/>\n"
"      <dash id=\"dash-8-1\" style=\"stroke-dasharray:8,1\"/>\n"
"      <dash id=\"dash-12-1\" style=\"stroke-dasharray:12,1\"/>\n"
"      <dash id=\"dash-24-1\" style=\"stroke-dasharray:24,1\"/>\n"
"      <dash id=\"dash-2-2\" style=\"stroke-dasharray:2,2\"/>\n"
"      <dash id=\"dash-3-3\" style=\"stroke-dasharray:3,3\"/>\n"
"      <dash id=\"dash-4-4\" style=\"stroke-dasharray:4,4\"/>\n"
"      <dash id=\"dash-6-6\" style=\"stroke-dasharray:6,6\"/>\n"
"      <dash id=\"dash-8-8\" style=\"stroke-dasharray:8,8\"/>\n"
"      <dash id=\"dash-12-12\" style=\"stroke-dasharray:12,12\"/>\n"
"      <dash id=\"dash-24-24\" style=\"stroke-dasharray:24,24\"/>\n"
"      <dash id=\"dash-2-4\" style=\"stroke-dasharray:2,4\"/>\n"
"      <dash id=\"dash-4-2\" style=\"stroke-dasharray:4,2\"/>\n"
"      <dash id=\"dash-2-6\" style=\"stroke-dasharray:2,6\"/>\n"
"      <dash id=\"dash-6-2\" style=\"stroke-dasharray:6,2\"/>\n"
"      <dash id=\"dash-4-8\" style=\"stroke-dasharray:4,8\"/>\n"
"      <dash id=\"dash-8-4\" style=\"stroke-dasharray:8,4\"/>\n"
"      <dash id=\"dash-2-1-012-1\" style=\"stroke-dasharray:2,1,0.5,1\"/>\n"
"      <dash id=\"dash-4-2-1-2\" style=\"stroke-dasharray:4,2,1,2\"/>\n"
"      <dash id=\"dash-8-2-1-2\" style=\"stroke-dasharray:8,2,1,2\"/>\n"
"      <dash id=\"dash-012-012\" style=\"stroke-dasharray:0.5,0.5\"/>\n"
"      <dash id=\"dash-014-014\" style=\"stroke-dasharray:0.25,0.25\"/>\n"
"      <dash id=\"dash-0110-0110\" style=\"stroke-dasharray:0.1,0.1\"/>\n"
"    </group>\n"
"  </group>\n"
"  <group id=\"colorselector\" page=\"0\"/>\n"
"  <group id=\"embedded\">\n"
"    <group id=\"swatches\"\n" 
"      panel_size=\"1\"\n"
"      panel_mode=\"1\"\n"
"      panel_wrap=\"0\"\n"
"      palette=\"Inkscape default\" />\n"
"  </group>\n"
"  <group id=\"dialogs\">\n"
"    <group id=\"toolbox\"/>\n"
"    <group id=\"fillstroke\"/>\n"
"    <group id=\"textandfont\"/>\n"
"    <group id=\"transformation\" applyseparately=\"0\"/>\n"
"    <group id=\"align\"/>\n"
"    <group id=\"xml\"/>\n"
"    <group id=\"find\"/>\n"
"    <group id=\"documentoptions\"/>\n"
"    <group id=\"preferences\"/>\n"
"    <group id=\"gradienteditor\"/>\n"
"    <group id=\"object\"/>\n"
"    <group id=\"export\">\n"
"      <group id=\"exportarea\"/>\n"
"      <group id=\"defaultxdpi\"/>\n"
"    </group>\n"
"    <group id=\"save_as\" default=\"\" append_extension=\"1\" path=\"\"/>\n"
"    <group id=\"open\" path=\"\"/>\n"
"    <group id=\"debug\" redirect=\"0\"/>\n"
"    <group id=\"clonetiler\" />\n"
"    <group id=\"gridtiler\" />\n"
"    <group id=\"extension-error\" show-on-startup=\"0\"/>\n"
"    <group id=\"memory\" />\n"
"    <group id=\"messages\" />\n"
"    <group id=\"swatches\" />\n"
"    <group id=\"iconpreview\" />\n"
"    <group id=\"aboutextensions\" />\n"
"    <group id=\"treeeditor\" />\n"
"    <group id=\"layers\" maxDepth=\"20\"/>\n"
"    <group id=\"extensioneditor\" />\n"
"    <group id=\"trace\" />\n"
"    <group id=\"script\" />\n"
"    <group id=\"input\" />\n"
"    <group id=\"colorpickerwindow\" />\n"
"  </group>\n"
"  <group id=\"printing\">\n"
"    <settings id=\"ps\"/>\n"
"    <group id=\"debug\" add-label-comments=\"0\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"options\">\n"
"    <group id=\"nudgedistance\" value=\"2\"/>\n"
"    <group id=\"rotationsnapsperpi\" value=\"12\"/>\n"
"    <group id=\"cursortolerance\" value=\"8.0\"/>\n"
"    <group id=\"dragtolerance\" value=\"4.0\"/>\n"
"    <group id=\"savewindowgeometry\" value=\"1\"/>\n"
"    <group id=\"defaultoffsetwidth\" value=\"2\"/>\n"
"    <group id=\"defaultscale\" value=\"2\"/>\n"
"    <group id=\"maxrecentdocuments\" value=\"36\"/>\n"
"    <group id=\"zoomincrement\" value=\"1.414213562\"/>\n"
"    <group id=\"keyscroll\" value=\"10\"/>\n"
"    <group id=\"wheelscroll\" value=\"40\"/>\n"
"    <group id=\"transientpolicy\" value=\"1\"/>\n"
"    <group id=\"scrollingacceleration\" value=\"0.35\"/>\n"
"    <group id=\"autoscrollspeed\" value=\"0.7\"/>\n"
"    <group id=\"autoscrolldistance\" value=\"-10\"/>\n"
"    <group id=\"simplifythreshold\" value=\"0.002\"/>\n"
"    <group id=\"dialogsskiptaskbar\" value=\"1\"/>\n"
"    <group id=\"arenatilescachesize\" value=\"8192\"/>\n"
"    <group id=\"preservetransform\" value=\"0\"/>\n"
"    <group id=\"clonecompensation\" value=\"1\"/>\n"
"    <group id=\"cloneorphans\" value=\"0\"/>\n"
"    <group id=\"stickyzoom\" value=\"0\"/>\n"
"    <group id=\"selcue\" value=\"2\"/>\n"
"    <group id=\"importbitmapsasimages\" value=\"1\"/>\n"
"    <group id=\"transform\" stroke=\"1\" rectcorners=\"1\" pattern=\"1\" gradient=\"1\" />\n"
"    <group id=\"kbselection\" inlayer=\"1\" onlyvisible=\"1\" onlysensitive=\"1\" />\n"
"    <group id=\"selection\" layerdeselect=\"1\" />\n"
"    <group id=\"createbitmap\" minsize=\"250\"/>\n"
"    <group id=\"compassangledisplay\" value=\"0\"/>\n"
"    <group id=\"maskobject\" topmost=\"1\" remove=\"1\"/>\n"
"  </group>\n"
"\n"
"  <group id=\"extensions\">"
"  </group>\n"
"\n"
"  <group id=\"desktop\""
"         style=\"\">\n"
"  </group>\n"
"\n"
"  <group id=\"devices\">\n"
"  </group>\n"
"\n"
"  <group\n"
"     id=\"iconpreview\">\n"
"    <group\n"
"       id=\"sizes\">\n"
"      <group\n"
"         id=\"default\">\n"
"        <group\n"
"           value=\"16\"\n"
"           show=\"1\"\n"
"           id=\"size16\" />\n"
"        <group\n"
"           value=\"24\"\n"
"           show=\"1\"\n"
"           id=\"size24\" />\n"
"        <group\n"
"           value=\"32\"\n"
"           show=\"1\"\n"
"           id=\"size32\" />\n"
"        <group\n"
"           value=\"48\"\n"
"           show=\"1\"\n"
"           id=\"size48\" />\n"
"        <group\n"
"           value=\"50\"\n"
"           show=\"0\"\n"
"           id=\"size50\" />\n"
"        <group\n"
"           value=\"64\"\n"
"           show=\"0\"\n"
"           id=\"size64\" />\n"
"        <group\n"
"           value=\"72\"\n"
"           show=\"0\"\n"
"           id=\"size72\" />\n"
"        <group\n"
"           value=\"80\"\n"
"           show=\"0\"\n"
"           id=\"size80\" />\n"
"        <group\n"
"           value=\"96\"\n"
"           show=\"0\"\n"
"           id=\"size96\" />\n"
"        <group\n"
"           value=\"128\"\n"
"           show=\"1\"\n"
"           id=\"size128\" />\n"
"        <group\n"
"           value=\"256\"\n"
"           show=\"0\"\n"
"           id=\"size256\" />\n"
"      </group>\n"
"    </group>\n"
"  </group>\n"
"  <group id = \"whiteboard\">\n"
"    <group id = \"server\" name = \"jabber.org\" port = \"5222\" username = \"\" ssl = \"0\"/>\n"
"    <group id = \"room\" name = \"inkboard\" server = \"gristle.org\"/>\n"
"  </group>\n"
"\n"
"</inkscape>\n";

#define PREFERENCES_SKELETON_SIZE (sizeof(preferences_skeleton) - 1)


#endif /* !SEEN_PREFERENCES_SKELETON_H */

/*
  Local Variables:
  mode:c++
  c-file-style:"stroustrup"
  c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
  indent-tabs-mode:nil
  fill-column:99
  End:
*/
// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
